==> bangs-0.8.0.tgz: package/PROPERTIES.md <==
# Properties

This file lists information about each property and its supported values.


## Layout
### `display`
```
.-d-n     none
.-d-bk    block
.-d-il    inline
.-d-ib    inline-block
.-d-fx    flex
.-d-li    list-item

-sK    true
-sM    true
-sG    true
-sT    true
```

### `position`
```
.-ps-s    static
.-ps-r    relative
.-ps-a    absolute
.-ps-f    fixed
.-ps-k    sticky
```

### `left`
```
.-l-a    auto
.-l-z    0
```

### `right`
```
.-r-a    auto
.-r-z    0
```

### `top`
```
.-t-a    auto
.-t-z    0
```

### `bottom`
```
.-b-a    auto
.-b-z    0
```

### `float`
```
.-fl-n    none
.-fl-l    left
.-fl-r    right
```

### `clear`
```
.-cl-n    none
.-cl-l    left
.-cl-r    right
.-cl-b    both
```

### `z-index`
```
.-z-a     auto
.-z-z      0
.-z-1      1
.-z-2      2
.-z-3      3
.-z-4      4
.-z-5      5
.-z-6      6
.-z-7      7
.-z--1    -1
.-z--2    -2
.-z--3    -3
.-z--4    -4
.-z--5    -5
.-z--6    -6
.-z--7    -7
```

### `vertical-align`
```
.-va-a     baseline
.-va-b     bottom
.-va-m     middle
.-va-t     top
.-va-tb    text-bottom
.-va-tt    text-top
.-va-sb    sub
.-va-st    super
```

### `flex-direction`
```
.-xd-r     row
.-xd-c     column
.-xd-rr    row-reverse
.-xd-cr    column-reverse
```

### `flex-wrap`
```
.-xw-n    nowrap
.-xw-w    wrap
.-xw-r    wrap-reverse
```

### `justify-content`
```
.-xjc-xs    flex-start
.-xjc-xe    flex-end
.-xjc-c     center
.-xjc-sb    space-between
.-xjc-sa    space-around
```

### `align-content`
```
.-xac-s     stretch
.-xac-xs    flex-start
.-xac-xe    flex-end
.-xac-c     center
.-xac-sb    space-between
.-xac-sa    space-around
```

### `align-items`
```
.-xai-s     stretch
.-xai-xs    flex-start
.-xai-xe    flex-end
.-xai-c     center
.-xai-b     baseline
```

### `align-self`
```
.-xas-a     auto
.-xas-s     stretch
.-xas-xs    flex-start
.-xas-xe    flex-end
.-xas-c     center
.-xas-b     baseline
```

### `order`
```
.-xo-z      0
.-xo-1      1
.-xo-2      2
.-xo-3      3
.-xo-4      4
.-xo-5      5
.-xo-6      6
.-xo-7      7
.-xo--1    -1
.-xo--2    -2
.-xo--3    -3
.-xo--4    -4
.-xo--5    -5
.-xo--6    -6
.-xo--7    -7

-sK    true
-sM    true
-sG    true
-sT    true
```


## Box Structure
### `box-sizing`
```
.-xz-c    content-box
.-xz-b    border-box
```

### `width`
```
.-w-1o1      100%
.-w-1o2      50%
.-w-2o2      100%
.-w-1o3      33.3%
.-w-2o3      66.7%
.-w-3o3      100%
.-w-1o4      25%
.-w-2o4      50%
.-w-3o4      75%
.-w-4o4      100%
.-w-1o5      20%
.-w-2o5      40%
.-w-3o5      60%
.-w-4o5      80%
.-w-5o5      100%
.-w-1o6      16.7%
.-w-2o6      33.3%
.-w-3o6      50%
.-w-4o6      66.7%
.-w-5o6      83.3%
.-w-6o6      100%
.-w-1o8      12.5%
.-w-2o8      25%
.-w-3o8      37.5%
.-w-4o8      50%
.-w-5o8      62.5%
.-w-6o8      75%
.-w-7o8      87.5%
.-w-8o8      100%
.-w-1o10     10%
.-w-2o10     20%
.-w-3o10     30%
.-w-4o10     40%
.-w-5o10     50%
.-w-6o10     60%
.-w-7o10     70%
.-w-8o10     80%
.-w-9o10     90%
.-w-10o10    100%

.-w-96px      96px
.-w-192px     192px
.-w-288px     288px
.-w-384px     384px
.-w-480px     480px
.-w-576px     576px
.-w-672px     672px
.-w-768px     768px
.-w-864px     864px
.-w-960px     960px
.-w-1056px    1056px
.-w-1152px    1152px
.-w-1248px    1248px
.-w-1344px    1344px
.-w-1440px    1440px

.-w-5em     5em
.-w-10em    10em
.-w-15em    15em
.-w-20em    20em
.-w-25em    25em
.-w-30em    30em
.-w-35em    35em
.-w-40em    40em
.-w-45em    45em
.-w-50em    50em
.-w-55em    55em
.-w-60em    60em
.-w-65em    65em
.-w-70em    70em
.-w-75em    75em
.-w-80em    80em
.-w-85em    85em
.-w-90em    90em

-sK    true
-sM    true
-sG    true
-sT    true
```

### `padding-*`
```
.-pl  .-pr  .-pt  .-pb  .-ph  .-pv  .-pa
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-z    0
-q    0.25rem
-h    0.5rem
-1    1rem
-2    2rem
-4    4rem
-8    8rem
-g    16rem

-sK    true
-sM    true
-sG    true
-sT    true
```

### `margin-*`
```
.-ml  .-mr  .-mt  .-mb  .-mh  .-mv  .-ma
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-a    auto
-z    0
-q    0.25rem
-h    0.5rem
-1    1rem
-2    2rem
-4    4rem
-8    8rem
-g    16rem
--q    -0.25rem
--h    -0.5rem
--1    -1rem
--2    -2rem
--4    -4rem
--8    -8rem
--g    -16rem

-sK    true
-sM    true
-sG    true
-sT    true
```


## Text Structure
### `font-style`
```
.-fs-n    normal
.-fs-t    italic

-h        true
```

### `font-variant`
```
.-fv-n    normal
.-fv-s    small-caps

-h        true
```

### `font-weight`
```
.-fw-n    normal
.-fw-b    bold
.-fw-1    100
.-fw-2    200
.-fw-3    300
.-fw-4    400
.-fw-5    500
.-fw-6    600
.-fw-7    700
.-fw-8    800
.-fw-9    900

-h        true
```

### `font-size`
```
.-fz-z    0
.-fz-q    0.25rem
.-fz-h    0.5rem
.-fz-1    1rem
.-fz-2    2rem
.-fz-4    4rem
```

### `font-family`
```
.-ff-ss    sans-serif
.-ff-sf    serif
.-ff-ms    monospace
.-ff-fy    fantasy
.-ff-cs    cursive
```

### `line-height`
```
.-lh-n    normal
.-lh-z    0
```

### `letter-spacing`
```
.-ls-n    normal
.-ls-z    0
```

### `word-spacing`
```
.-ws-n    normal
.-ws-z    0
```

### `text-align`
```
.-ta-l    left
.-ta-r    right
.-ta-c    center
.-ta-j    justify
```

### `text-indent`
```
.-ti-z    0
```

### `white-space`
```
.-sp-n     normal
.-sp-nw    nowrap
.-sp-pr    pre
.-sp-pw    pre-wrap
.-sp-pl    pre-line
```

### `overflow-wrap`
```
.-ww-n    normal
.-ww-b    break-word
```

### `column-count`
```
.-cc-a    auto
.-cc-1    1
.-cc-2    2
.-cc-3    3
.-cc-4    4
.-cc-5    5
.-cc-6    6
```

### `column-width`
```
.-cw-a    auto
```

### `page-break-[before|after]`
```
.-pbb  .-pba
```
(for `-before` or `-after`, respectively)
```
-a    auto
-t    always
-f    avoid

NOTE: no support for any media queries
```


## Box Cosmetics
### `border-*-style`
```
.-rls  .-rrs  .-rts  .-rbs  .-rhs  .-rvs  .-ras
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-n     none
-h     hidden
-s     solid
-do    dotted
-da    dashed
-db    double
-gv    groove
-rg    ridge
-is    inset
-os    outset
```

### `border-*-color`
```
.-rlc  .-rrc  .-rtc  .-rbc  .-rhc  .-rvc  .-rac
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-t    transparent
-c    currentColor
-b    #000000
-w    #ffffff
```

### `background-image`
```
.-bi-n    none
```

### `background-position`
```
.-bp-l     left
.-bp-r     right
.-bp-c     center
.-bp-t     top
.-bp-b     bottom
.-bp-lt    left   top
.-bp-lc    left   center
.-bp-lb    left   bottom
.-bp-ct    center top
.-bp-cc    center center
.-bp-cb    center bottom
.-bp-rt    right  top
.-bp-rc    right  center
.-bp-rb    right  bottom
```

### `background-size`
```
.-bz-a    auto
.-bz-s    contain
.-bz-l    cover
```

### `background-repeat`
```
.-br-n    no-repeat
.-br-a    repeat
.-br-x    repeat-x
.-br-y    repeat-y
```

### `background-attachment`
```
.-ba-f    fixed
.-ba-s    scroll
.-ba-l    local
```

### `background-origin`
```
.-bo-c    content-box
.-bo-p    padding-box
.-bo-b    border-box
```

### `background-clip`
```
.-bk-c    content-box
.-bk-p    padding-box
.-bk-b    border-box
```

### `background-color`
```
.-bc-t    transparent
.-bc-c    currentColor
.-bc-b    #000000
.-bc-w    #ffffff

-h        true
```

### `box-shadow`
```
.-xs-n    none
```

### `overflow`
```
.-of-a    auto
.-of-v    visible
.-of-h    hidden
.-of-s    scroll
```

### `opacity`
```
.-o-z    0.0
.-o-h    0.5
.-o-1    1.0

-h        true
```

### `visibility`
```
.-v-v    visible
.-v-h    hidden
.-v-c    collapse
```


## Text Cosmetics
### `text-transform`
```
.-tt-n    none
.-tt-c    capitalize
.-tt-h    uppercase
.-tt-l    lowercase

-h        true
```

### `text-decoration`
```
.-td-n     none
.-td-ul    underline
.-td-ol    overline
.-td-lt    line-through

-h        true
```

### `text-shadow`
```
.-ts-n    none
```

### `text-overflow`
```
.-to-c    clip
.-to-e    ellipsis
```

### `list-style-type`
```
.-lst-n     none
.-lst-dz    decimal-leading-zero
.-lst-ur    upper-roman
.-lst-ua    upper-alpha
.-lst-dc    decimal
.-lst-la    lower-alpha
.-lst-lr    lower-roman
.-lst-lg    lower-greek
.-lst-d     disc
.-lst-c     circle
.-lst-s     square
```

### `list-style-position`
```
.-lsp-os    outside
.-lsp-is    inside
```

### `list-style-image`
```
.-lsi-n     none
```

### `color`
```
.-c-t    transparent
.-c-c    currentColor
.-c-b    #000000
.-c-w    #ffffff

-h       true
```

==> bangs-0.9.1.tgz: package/PROPERTIES.md <==
# Properties

This file lists information about each property and its supported values.


## Layout

### `display`
```
.-d-n     none
.-d-bk    block
.-d-il    inline
.-d-ib    inline-block
.-d-fx    flex
.-d-li    list-item

-sK    true
-sM    true
-sG    true
-sT    true
```

### `position`
```
.-ps-s    static
.-ps-r    relative
.-ps-a    absolute
.-ps-f    fixed
.-ps-k    sticky
```

### `left`
```
.-l-a    auto
.-l-z    0
```

### `right`
```
.-r-a    auto
.-r-z    0
```

### `top`
```
.-t-a    auto
.-t-z    0
```

### `bottom`
```
.-b-a    auto
.-b-z    0
```

### `float`
```
.-fl-n    none
.-fl-l    left
.-fl-r    right
```

### `clear`
```
.-cl-n    none
.-cl-l    left
.-cl-r    right
.-cl-b    both
```

### `z-index`
```
.-z-a     auto
.-z-z      0
.-z-1      1
.-z-2      2
.-z-3      3
.-z-4      4
.-z-5      5
.-z-6      6
.-z-7      7
.-z--1    -1
.-z--2    -2
.-z--3    -3
.-z--4    -4
.-z--5    -5
.-z--6    -6
.-z--7    -7
```

### `vertical-align`
```
.-va-a     baseline
.-va-b     bottom
.-va-m     middle
.-va-t     top
.-va-tb    text-bottom
.-va-tt    text-top
.-va-sb    sub
.-va-st    super
```

### `flex-direction`
```
.-xd-r     row
.-xd-c     column
.-xd-rr    row-reverse
.-xd-cr    column-reverse
```

### `flex-wrap`
```
.-xw-n    nowrap
.-xw-w    wrap
.-xw-r    wrap-reverse
```

### `justify-content`
```
.-xjc-xs    flex-start
.-xjc-xe    flex-end
.-xjc-c     center
.-xjc-sb    space-between
.-xjc-sa    space-around
```

### `align-content`
```
.-xac-s     stretch
.-xac-xs    flex-start
.-xac-xe    flex-end
.-xac-c     center
.-xac-sb    space-between
.-xac-sa    space-around
```

### `align-items`
```
.-xai-s     stretch
.-xai-xs    flex-start
.-xai-xe    flex-end
.-xai-c     center
.-xai-b     baseline
```

### `align-self`
```
.-xas-a     auto
.-xas-s     stretch
.-xas-xs    flex-start
.-xas-xe    flex-end
.-xas-c     center
.-xas-b     baseline
```

### `order`
```
.-xo-z      0
.-xo-1      1
.-xo-2      2
.-xo-3      3
.-xo-4      4
.-xo-5      5
.-xo-6      6
.-xo-7      7
.-xo--1    -1
.-xo--2    -2
.-xo--3    -3
.-xo--4    -4
.-xo--5    -5
.-xo--6    -6
.-xo--7    -7

-sK    true
-sM    true
-sG    true
-sT    true
```

### `flex`
```
.-x-a    auto
.-x-c    content
.-x-h    0.5
.-x-1    1
.-x-2    2

.-x-1o1      100%
.-x-1o2      50%
.-x-2o2      100%
.-x-1o3      33.3%
.-x-2o3      66.7%
.-x-3o3      100%
.-x-1o4      25%
.-x-2o4      50%
.-x-3o4      75%
.-x-4o4      100%
.-x-1o5      20%
.-x-2o5      40%
.-x-3o5      60%
.-x-4o5      80%
.-x-5o5      100%
.-x-1o6      16.7%
.-x-2o6      33.3%
.-x-3o6      50%
.-x-4o6      66.7%
.-x-5o6      83.3%
.-x-6o6      100%
.-x-1o8      12.5%
.-x-2o8      25%
.-x-3o8      37.5%
.-x-4o8      50%
.-x-5o8      62.5%
.-x-6o8      75%
.-x-7o8      87.5%
.-x-8o8      100%
.-x-1o10     10%
.-x-2o10     20%
.-x-3o10     30%
.-x-4o10     40%
.-x-5o10     50%
.-x-6o10     60%
.-x-7o10     70%
.-x-8o10     80%
.-x-9o10     90%
.-x-10o10    100%

-sK    true
-sM    true
-sG    true
-sT    true
```


## Box Structure

### `box-sizing`
```
.-kz-c    content-box
.-kz-b    border-box
```

### `width`
```
.-w-a    auto
.-w-z    0

.-w-1o1      100%
.-w-1o2      50%
.-w-2o2      100%
.-w-1o3      33.3%
.-w-2o3      66.7%
.-w-3o3      100%
.-w-1o4      25%
.-w-2o4      50%
.-w-3o4      75%
.-w-4o4      100%
.-w-1o5      20%
.-w-2o5      40%
.-w-3o5      60%
.-w-4o5      80%
.-w-5o5      100%
.-w-1o6      16.7%
.-w-2o6      33.3%
.-w-3o6      50%
.-w-4o6      66.7%
.-w-5o6      83.3%
.-w-6o6      100%
.-w-1o8      12.5%
.-w-2o8      25%
.-w-3o8      37.5%
.-w-4o8      50%
.-w-5o8      62.5%
.-w-6o8      75%
.-w-7o8      87.5%
.-w-8o8      100%
.-w-1o10     10%
.-w-2o10     20%
.-w-3o10     30%
.-w-4o10     40%
.-w-5o10     50%
.-w-6o10     60%
.-w-7o10     70%
.-w-8o10     80%
.-w-9o10     90%
.-w-10o10    100%

.-w-96px      96px
.-w-192px     192px
.-w-288px     288px
.-w-384px     384px
.-w-480px     480px
.-w-576px     576px
.-w-672px     672px
.-w-768px     768px
.-w-864px     864px
.-w-960px     960px
.-w-1056px    1056px
.-w-1152px    1152px
.-w-1248px    1248px
.-w-1344px    1344px
.-w-1440px    1440px

.-w-5em     5em
.-w-10em    10em
.-w-15em    15em
.-w-20em    20em
.-w-25em    25em
.-w-30em    30em
.-w-35em    35em
.-w-40em    40em
.-w-45em    45em
.-w-50em    50em
.-w-55em    55em
.-w-60em    60em
.-w-65em    65em
.-w-70em    70em
.-w-75em    75em
.-w-80em    80em
.-w-85em    85em
.-w-90em    90em

-sK    true
-sM    true
-sG    true
-sT    true
```

### `padding-*`
```
.-pl  .-pr  .-pt  .-pb  .-ph  .-pv  .-pa
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-z    0
-q    0.25rem
-h    0.5rem
-1    1rem
-2    2rem
-4    4rem
-8    8rem
-g    16rem

-sK    true
-sM    true
-sG    true
-sT    true
```

### `margin-*`
```
.-ml  .-mr  .-mt  .-mb  .-mh  .-mv  .-ma
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-a    auto
-z    0
-q    0.25rem
-h    0.5rem
-1    1rem
-2    2rem
-4    4rem
-8    8rem
-g    16rem
--q    -0.25rem
--h    -0.5rem
--1    -1rem
--2    -2rem
--4    -4rem
--8    -8rem
--g    -16rem

-sK    true
-sM    true
-sG    true
-sT    true
```


## Text Structure

### `font-style`
```
.-fs-n    normal
.-fs-t    italic

-h        true
```

### `font-variant`
```
.-fv-n    normal
.-fv-s    small-caps

-h        true
```

### `font-weight`
```
.-fw-n      normal
.-fw-b      bold
.-fw-100    100
.-fw-200    200
.-fw-300    300
.-fw-400    400
.-fw-500    500
.-fw-600    600
.-fw-700    700
.-fw-800    800
.-fw-900    900

-h        true
```

### `font-size`
```
.-fz-z    0
```

### `font-family`
```
.-ff-ss    sans-serif
.-ff-sf    serif
.-ff-ms    monospace
.-ff-fy    fantasy
.-ff-cs    cursive
```

### `line-height`
```
.-lh-n    normal
.-lh-z    0
```

### `letter-spacing`
```
.-ls-n    normal
.-ls-z    0
```

### `word-spacing`
```
.-ws-n    normal
.-ws-z    0
```

### `text-align`
```
.-ta-l    left
.-ta-r    right
.-ta-c    center
.-ta-j    justify
```

### `text-indent`
```
.-ti-z    0
```

### `white-space`
```
.-sp-n     normal
.-sp-nw    nowrap
.-sp-pr    pre
.-sp-pw    pre-wrap
.-sp-pl    pre-line
```

### `overflow-wrap`
```
.-ww-n    normal
.-ww-b    break-word
```

### `column-count`
```
.-cc-a    auto
.-cc-1    1
.-cc-2    2
.-cc-3    3
.-cc-4    4
.-cc-5    5
.-cc-6    6
```

### `column-width`
```
.-cw-a    auto
```

### `page-break-[before|after]`
```
.-pbb  .-pba
```
(for `-before` or `-after`, respectively)
```
-a    auto
-t    always
-f    avoid

NOTE: no support for any media queries
```


## Box Cosmetics

### `border-*-style`
```
.-rls  .-rrs  .-rts  .-rbs  .-rhs  .-rvs  .-ras
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-n     none
-h     hidden
-s     solid
-do    dotted
-da    dashed
-db    double
-gv    groove
-rg    ridge
-is    inset
-os    outset
```

### `border-*-color`
```
.-rlc  .-rrc  .-rtc  .-rbc  .-rhc  .-rvc  .-rac
```
(for `-left`, `-right`, `-top`, `-bottom`, ‘horizontal’, ‘vertical’, or ‘all’, respectively)
```
-t    transparent
-c    currentColor
-b    #000000
-w    #ffffff
```

### `background-image`
```
.-bi-n    none
```

### `background-position`
```
.-bp-l     left
.-bp-r     right
.-bp-c     center
.-bp-t     top
.-bp-b     bottom
.-bp-lt    left   top
.-bp-lc    left   center
.-bp-lb    left   bottom
.-bp-ct    center top
.-bp-cc    center center
.-bp-cb    center bottom
.-bp-rt    right  top
.-bp-rc    right  center
.-bp-rb    right  bottom
```

### `background-size`
```
.-bz-a    auto
.-bz-s    contain
.-bz-l    cover
```

### `background-repeat`
```
.-br-n    no-repeat
.-br-a    repeat
.-br-x    repeat-x
.-br-y    repeat-y
```

### `background-attachment`
```
.-ba-f    fixed
.-ba-s    scroll
.-ba-l    local
```

### `background-origin`
```
.-bo-c    content-box
.-bo-p    padding-box
.-bo-b    border-box
```

### `background-clip`
```
.-bk-c    content-box
.-bk-p    padding-box
.-bk-b    border-box
```

### `background-color`
```
.-bc-t    transparent
.-bc-c    currentColor
.-bc-b    #000000
.-bc-w    #ffffff

-h        true
```

### `box-shadow`
```
.-ks-n    none
```

### `overflow`
```
.-of-a    auto
.-of-v    visible
.-of-h    hidden
.-of-s    scroll
```

### `opacity`
```
.-o-z    0.0
.-o-h    0.5
.-o-1    1.0

-h        true
```

### `visibility`
```
.-v-v    visible
.-v-h    hidden
.-v-c    collapse
```


## Text Cosmetics

### `text-transform`
```
.-tt-n    none
.-tt-c    capitalize
.-tt-h    uppercase
.-tt-l    lowercase

-h        true
```

### `text-decoration`
```
.-td-n     none
.-td-ul    underline
.-td-ol    overline
.-td-lt    line-through

-h        true
```

### `text-shadow`
```
.-ts-n    none
```

### `text-overflow`
```
.-to-c    clip
.-to-e    ellipsis
```

### `list-style-type`
```
.-lst-n     none
.-lst-dz    decimal-leading-zero
.-lst-ur    upper-roman
.-lst-ua    upper-alpha
.-lst-dc    decimal
.-lst-la    lower-alpha
.-lst-lr    lower-roman
.-lst-lg    lower-greek
.-lst-d     disc
.-lst-c     circle
.-lst-s     square
```

### `list-style-position`
```
.-lsp-os    outside
.-lsp-is    inside
```

### `list-style-image`
```
.-lsi-n     none
```

### `color`
```
.-c-t    transparent
.-c-c    currentColor
.-c-b    #000000
.-c-w    #ffffff

-h       true
```
